@@ -1,5 +1,3 @@
-# nba <- read.csv("http://datasets.flowingdata.com/ppg2008.csv")
-
 data(flea)
 
 test_that("limits", {
@@ -84,7 +82,7 @@ test_that("further options", {
     "geom-tile-no-limits",
     ggcorr(flea[, -1], geom = "tile", limits = FALSE)
   )
-  expect_error(ggcorr(flea[, -1], layout.exp = "a"), "incorrect layout.exp")
+  expect_error(ggcorr(flea[, -1], layout.exp = "a"), "incorrect `layout.exp`")
   ggally_expect_doppelganger("layout.exp", ggcorr(flea[, -1], layout.exp = 1))
 })
 
